from django.db import models
from django.conf import settings
from django.contrib.auth.models import User
from django.contrib.sites.models import Site
from django.template.defaultfilters import slugify
from django_countries.fields import CountryField

SECURITY_QUESTION_CHOICES = (
	('first_pet_name', 'What was the name of your first pet?'),
)

class Profile(models.Model):
    	user = models.OneToOneField(User)
    	other_name = models.CharField(
        max_length=200,
        blank=True,
        null=True,
        help_text=""
    )
    	about = models.TextField(
        blank=True,
        null=True,
        help_text=""
    )
    	employer = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	position = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	gender = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	ethnicity = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	facebook = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	twitter = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	linkedin = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	blog = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	image = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
    	cover_image = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
	mobile = models.CharField(
		max_length=20,
		blank=True,
		null=True,
		help_text=""
	)
	email_activation_code = models.TextField(
        blank=True,
        null=True,
        help_text=""
    )
	mobile_activation_code = models.CharField(
		max_length=100,
        blank=True,
        null=True,
        help_text=""
    )
	two_facter_enabled = models.BooleanField(default=False)
	security_question = models.CharField(
		max_length=100,
        blank=True,
        null=True,
        help_text="",
		choices=SECURITY_QUESTION_CHOICES
    )
	security_question_answer = models.CharField(
		max_length=100,
        blank=True,
        null=True,
        help_text=""
    )
    	def __str__(self):
        	return self.user.first_name + ' ' + self.user.last_name


from django.shortcuts import render


def index(request):
    context = {}
    return render(request, 'blog/templates/index.html', context )

def post(request, slug):
    context = {}
    return render(request, 'blog/templates/post.html', context )



import random
import hashlib
import uuid
import string


def generate_random_number(length, valid_characters='0123456789'):
    key = ''
    for i in range(length):
        key = '%s%s' % (key, random.choice(valid_characters))
    return key


def generate_random_key(length, valid_characters='abcdefghijklmnopqrstuvwxyz0123456789'):
    key = ''
    for i in range(length):
        key = '%s%s' % (key, random.choice(valid_characters))
    return key


def create_hash(length):
    # uuid is used to generate a random number
    data = uuid.uuid4().hex
    h = hashlib.new(length)
    h.update(data)
    return h.hexdigest()


def generate_uuid():
    data = uuid.uuid4().hex
    return data


def id_generator(size=9, chars=string.ascii_uppercase + string.digits):
    return ''.join(random.choice(chars) for _ in range(size))



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-22 12:38
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('other_name', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('about', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('employer', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('position', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('gender', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('ethnicity', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('facebook', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('twitter', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('linkedin', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('blog', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('image', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('cover_image', models.CharField(blank=True, help_text=b'', max_length=200, null=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-22 15:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('people', '0002_auto_20170822_1522'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profile',
            name='security_question',
            field=models.CharField(blank=True, choices=[(b'first_pet_name', b'What was the name of your first pet?')], help_text=b'', max_length=100, null=True),
        ),
    ]



from api.v1.serializers.users import UserSerializer


def jwt_response_handler(token, user=None, request=None):
    return {
        'token': token,
        'user': UserSerializer(user, context={'request': request}).data
    }



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-22 15:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('people', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='email_activation_code',
            field=models.TextField(blank=True, help_text=b'', null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='mobile',
            field=models.CharField(blank=True, help_text=b'', max_length=20, null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='mobile_activation_code',
            field=models.CharField(blank=True, help_text=b'', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='security_question',
            field=models.CharField(blank=True, help_text=b'', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='security_question_answer',
            field=models.CharField(blank=True, help_text=b'', max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='profile',
            name='two_facter_enabled',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='profile',
            name='about',
            field=models.TextField(blank=True, help_text=b'', null=True),
        ),
    ]
